@@ -19,18 +19,18 @@
 downloadOMLObject = function(id, object = c("data", "task", "flow", "run"), overwrite = FALSE, cache.only = FALSE, verbosity = NULL) {
   id = asCount(id)
   assertChoice(object, choices = c("data", "task", "flow", "run"))
-
+  
   # look if desired file(s) are already in cache
   cap.obj = object
   substr(cap.obj, 1, 1) = toupper(substr(object, 1, 1))
   f = do.call(paste0("findCached", cap.obj), list(id))
-
+  
   # if cache.only option is active and there is a file which is not in cache, stop with an error
   # FIXME: This does not work if there is flow.xml but the corresponding source or binary files were removed;
   #   can be fixed if findCachedFlow outputs the file from source_url or binary_url if there is one
   if (all(vlapply(f, function(X) !X$found)) & cache.only)
     stopf("%s '%i' files not found in cache with option 'cache.only'.", cap.obj, id)
-
+  
   # download and write xml if not found in cache (and if overwrite is true)
   xml.ind = stri_endswith_fixed(names(f), "xml")
   file.ind = which(!xml.ind)
@@ -56,7 +56,7 @@ downloadOMLObject = function(id, object = c("data", "task", "flow", "run"), over
   #   unlink(f[[xml.ind]]$path, recursive = TRUE, force = TRUE)
   #   stop(doc)
   # }
-
+  
   ## now download files
   # get url of files
   if (object == "data") {
@@ -95,7 +95,7 @@ downloadOMLObject = function(id, object = c("data", "task", "flow", "run"), over
       })
     url = url[url != ""]
   }
-
+  
   # download files if there is an url
   if (!is.null(url) & length(url) != 0) {
     if (f[[file.ind]]$found & !overwrite) {
@@ -104,7 +104,10 @@ downloadOMLObject = function(id, object = c("data", "task", "flow", "run"), over
       url = stri_trim_both(url)
       showInfo(verbosity, "Downloading from '%s' to '%s'", url, f[[file.ind]]$path)
       resp = GET(url)
-      writeBin(content(resp), f[[file.ind]]$path)
+      content.resp = content(resp)
+      if (is.vector(content.resp))
+        writeBin(content.resp, f[[file.ind]]$path) else
+          warningf("File not found at '%s'.", url)      
       # set found = TRUE if downloaded file is in cache
       if (file.exists(f[[file.ind]]$path)) f[[file.ind]]$found = TRUE
     }
@@ -112,3 +115,17 @@ downloadOMLObject = function(id, object = c("data", "task", "flow", "run"), over
   return(list(doc = doc, files = f))
 }
 
+# helper to get files either from test or from main server if it failed
+# get.file = function(url, switch.server.if.failing = TRUE) {
+#   resp = GET(url)
+#   if (!is.vector(content(resp)) & switch.server.if.failing) {
+#     server.url = ifelse(stri_detect_fixed(url, "https://test"), "https://www", "https://test")
+#     change.url = stri_paste(server.url, stri_match_first(url, regex = "[.]openml.*", ""))
+#     head.status = httr::headers(resp)$status
+#     if (!is.null(head.status))
+#       messagef("The url '%s' has the header status: %s.", url, head.status)
+#     messagef("Trying to get the file from '%s'.", change.url)
+#     resp = GET(change.url)
+#   }
+#   return(resp)
+# }
